==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/wavpack/translations/wavpack_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Wtyczka WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Pliki WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="160"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O wtyczce WavPack Audio</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="161"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Wtyczka WavPack dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="162"/>
        <source>WavPack library version:</source>
        <translation>Wersja biblioteki WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="164"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/wavpack/translations/wavpack_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>Wtyczka WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>Pliki WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="153"/>
        <source>About WavPack Audio Plugin</source>
        <translation>O wtyczce WavPack Audio</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="154"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Wtyczka WavPack dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="155"/>
        <source>WavPack library version:</source>
        <translation>Wersja biblioteki WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="157"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
</context>
</TS>
